use crate::util::{junk, random::RandomGen, validate};

use serenity::builder::{CreateCommand, CreateCommandOption};
use serenity::model::application::{CommandOptionType, ResolvedOption, ResolvedValue};

pub async fn run(options: &[ResolvedOption<'_>]) -> String {
    // check if options array is empty first
    if options.is_empty() {
        let mut rng = RandomGen::new();
        return rng.range_random_from_one(999).to_string();
    }

    // options exist, process first option
    if let Some(ResolvedOption {
        value: ResolvedValue::String(input),
        ..
    }) = options.first()
    {
        let mut rng = RandomGen::new();
        return match validate::parse_str_into_num::<i32>(input.trim()) {
            Some(n) => rng.range_random_from_one(n).to_string(),
            None => return junk::get_random_insult(),
        };
    } else {
        junk::get_random_insult()
    }
}

pub fn register() -> CreateCommand {
    CreateCommand::new("random")
        .description("Start a random dice roll, commonly used for deathrolls!")
        .add_option(
            CreateCommandOption::new(
                CommandOptionType::String,
                "limit",
                "Set an upper limit to display a random number between 1 and the specified number.",
            )
            .required(false),
        )
}
